# Kamodo

Kamodo is a tool for interacting with space weather models for use in visualization, research, education, and operations. Kamodo provides access to space weather models through readers and interpolators, and returns results in the users's preferred units coordinate system.

## Resources
SciVision, Inc

    https://www.scivision.co/f2py-running-fortran-code-in-python-on-windows/
    https://github.com/scivision/f2py-examples

Tutorial: Using Fortran from Python

    http://arogozhnikov.github.io/2015/11/29/using-fortran-from-python.html

See ```Prototypes/Fortran2Python_example.ipynb``` for details

Numpy documentation for f2py

    https://docs.scipy.org/doc/numpy/f2py/python-usage.html

## Setup

See notebooks

create an enviornment for python 3.6 to get started

    conda create -n py36 python=3.6 jupyter
